mod conversions;
pub mod git_repository;
mod git_url;

use derive_more::Display;

#[derive(Clone, Debug, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
pub enum Force {
    None,
    ForceWithLease { expected_sha: String },
}

impl std::fmt::Display for Force {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Self::None => write!(f, "fast-forward"),
            Self::ForceWithLease { expected_sha } => write!(f, "force-if-from:{expected_sha}"),
        }
    }
}

pub use git_repository::GitCloneError;
pub use git_repository::GitOpenError;
pub use git_repository::GitRepository;
pub use git_url::GitUrl;

#[derive(Debug, Copy, Clone, Display, Hash, PartialEq, Eq)]
pub enum Direction {
    /// Push local changes to the remote.
    #[display("push")]
    Push,
    /// Fetch changes from the remote to the local repository.
    #[display("fetch")]
    Fetch,
}

#[cfg(test)]
pub mod test_helpers;

#[cfg(test)]
mod tests;
