//
use kameo::message::{Context, Message};

use crate::prelude::*;
use crate::{
    core::server::AppConfig,
    file_watcher::FileUpdated,
    server::actor::{messages::ReceiveAppConfig, ServerActor},
    tell,
};

impl Message<FileUpdated> for ServerActor {
    type Reply = Result<()>;

    async fn handle(
        &mut self,
        _msg: FileUpdated,
        ctx: &mut Context<Self, Self::Reply>,
    ) -> Self::Reply {
        debug!("FileUpdated");
        match AppConfig::load(&self.fs) {
            Ok(app_config) => Ok(tell!(
                "server",
                ctx.actor_ref(),
                ReceiveAppConfig::new(app_config)
            )?),
            Err(err) => {
                error!("Failed to load config file. Error: {err}");
                ctx.actor_ref().kill();
                Ok(())
            }
        }
    }
}
